Account

Struct Account 

pub struct Account {
    pub name: String,
    pub balance: Decimal,
    pub id: String,
}
Account with balance of rust_decimal type, name and id

Fields

name: Stringbalance: Decimalid: String

Implementations

Source

impl Account

Implement Account functionality

pub fn new(name: String, balance: Decimal, id: String) -> Account

pub fn deposit(&mut self, amount: Decimal)

deposit amount to account, amount should be positive if amount is negative, nothing will happen

pub fn withdraw(&mut self, amount: Decimal)

Withdraw amount from account, balance should be positive after withdraw if amount is negative, nothing will happen if amount is positive and balance is less than amount, nothing will happen